@@ -27,8 +27,12 @@ from reliontomo.contants import V3_0, RELIONTOMO_DEFAULT, RELION
 
 _logo = "relion_logo.png"
 _references = ['Scheres2012a', 'Scheres2012b', 'Kimanius2016', 'Zivanov2018']
-__version__ = '3.0.0'
+__version__ = '3.0.1'
 
 
 class Plugin(relion.Plugin):
-    _supportedVersions = [V3_0]
\ No newline at end of file
+    _supportedVersions = [V3_0]
+
+    @classmethod
+    def defineBinaries(cls, env):
+        pass
